==> janis-pipelines.pipelines-0.11.2.tar.gz: janis-pipelines.pipelines-0.11.2/setup.py <==
from setuptools import setup, find_packages

######## SHOULDN'T NEED EDITS BELOW THIS LINE ########

vsn = {}
with open("./janis_pipelines/__meta__.py") as fp:
    exec(fp.read(), vsn)
version = vsn["__version__"]
description = vsn["description"]

with open("./README.md") as readme:
    long_description = readme.read()

setup(
    name="janis-pipelines.pipelines",
    version=version,
    description=description,
    url="https://github.com/PMCC-BioinformaticsCore/janis-pipelines",
    author="Michael Franklin",
    author_email="michael.franklin@petermac.org",
    license="GNU",
    packages=["janis_pipelines"]
    + ["janis_pipelines." + p for p in sorted(find_packages("./janis_pipelines"))],
    entry_points={
        "janis.extension": ["pipelines=janis_pipelines"],
        "janis.tools": ["pipelines=janis_pipelines"],
        "janis.pipelines": ["bioinformatics=janis_pipelines"],
    },
    install_requires=[
        "janis-pipelines.core>=0.10.0",
        "janis-pipelines.bioinformatics>=0.10.0",
        "janis-pipelines.unix>=0.10.0",
    ],
    extras_require={
        "ci": [
            "keyring==21.4.0",
            "setuptools",
            "wheel",
            "twine",
        ],
    },
    zip_safe=False,
    long_description=long_description,
    long_description_content_type="text/markdown",
    classifiers=[
        "Development Status :: 2 - Pre-Alpha",
        "Intended Audience :: Developers",
        "Intended Audience :: Science/Research",
        "Topic :: Scientific/Engineering :: Bio-Informatics",
    ],
)

==> janis-pipelines.pipelines-0.12.0.tar.gz: janis-pipelines.pipelines-0.12.0/setup.py <==
from setuptools import setup, find_packages

######## SHOULDN'T NEED EDITS BELOW THIS LINE ########

vsn = {}
with open("./janis_pipelines/__meta__.py") as fp:
    exec(fp.read(), vsn)
version = vsn["__version__"]
description = vsn["description"]

with open("./README.md") as readme:
    long_description = readme.read()

setup(
    name="janis-pipelines.pipelines",
    version=version,
    description=description,
    url="https://github.com/PMCC-BioinformaticsCore/janis-pipelines",
    author="Michael Franklin",
    author_email="michael.franklin@petermac.org",
    license="GNU",
    packages=["janis_pipelines"]
    + ["janis_pipelines." + p for p in sorted(find_packages("./janis_pipelines"))],
    entry_points={
        "janis.extension": ["pipelines=janis_pipelines"],
        "janis.tools": ["pipelines=janis_pipelines"],
        "janis.pipelines": ["bioinformatics=janis_pipelines"],
    },
    install_requires=[
        # "janis-pipelines.core>=0.10.0",
        # "janis-pipelines.bioinformatics>=0.10.0",
        "janis-pipelines.unix>=0.10.0",
    ],
    extras_require={
        "ci": [
            "keyring==21.4.0",
            "setuptools",
            "wheel",
            "twine",
        ],
    },
    zip_safe=False,
    long_description=long_description,
    long_description_content_type="text/markdown",
    classifiers=[
        "Development Status :: 2 - Pre-Alpha",
        "Intended Audience :: Developers",
        "Intended Audience :: Science/Research",
        "Topic :: Scientific/Engineering :: Bio-Informatics",
    ],
)
